@@ -358,24 +358,17 @@ class CloudRegion(AaiElement):  # pylint: disable=too-many-instance-attributes
                 CloudRegion has no relationship with any Complex
 
         """
-        try:
-            for relationship in self.relationships:
-                if relationship.related_to == "complex":
-                    physical_location_id: Optional[str] = relationship.get_relationship_data(
-                        "complex.physical-location-id"
+        for relationship in self.relationships:
+            if relationship.related_to == "complex":
+                physical_location_id: Optional[str] = relationship.get_relationship_data(
+                    "complex.physical-location-id"
+                )
+                if physical_location_id is not None:
+                    return Complex.get_by_physical_location_id(
+                        physical_location_id
                     )
-                    if physical_location_id is not None:
-                        try:
-                            return Complex.get_by_physical_location_id(
-                                physical_location_id
-                            )
-                        except ResourceNotFound:
-                            self._logger.error("Complex with %s physical location id does "
-                                               "not exist", physical_location_id)
-                    self._logger.error("Invalid Complex relationship!")
-                    return None
-        except ResourceNotFound:
-            self._logger.debug("Cloud region %s has no relationships", self.cloud_region_id)
+                self._logger.error("Invalid Complex relationship!")
+                return None
         self._logger.debug("Cloud region %s has no related complex", self.cloud_region_id)
         return None
 
@@ -422,19 +415,6 @@ class CloudRegion(AaiElement):  # pylint: disable=too-many-instance-attributes
             resource_version=response.get("resource-version"),
         )
 
-    def get_tenants_by_name(self, tenant_name: str) -> Iterator["Tenant"]:
-        """Get tenants with given name.
-
-        Args:
-            tenant_name (str): Tenant name
-
-        Returns:
-            Iterator[Tenant]: Iterate through cloud region tenants with given name
-
-        """
-        return (tenant for tenant in self.tenants if tenant.name == tenant_name)
-
-
     def get_availability_zone_by_name(self,
                                       zone_name: str) -> "AvailabilityZone":
         """Get availability zone with provided Name.
