@@ -3,113 +3,35 @@
 # SPDX-License-Identifier: Apache-2.0
 """Instantion module."""
 from abc import ABC
-from dataclasses import dataclass, field
-from typing import Any, Dict, Iterable, List, Optional
+from dataclasses import dataclass
+from typing import Iterable, Optional
 from uuid import uuid4
 from warnings import warn
-
-from dacite import from_dict
-
-from onapsdk.aai.business.owning_entity import OwningEntity
 from onapsdk.exceptions import (
     APIError, InvalidResponse, ParameterError, ResourceNotFound, StatusError
 )
+
 from onapsdk.onap_service import OnapService
 from onapsdk.sdnc import NetworkPreload, VfModulePreload
 from onapsdk.sdc.service import Network, Service as SdcService, Vnf, VfModule
 from onapsdk.utils.jinja import jinja_env
 from onapsdk.utils.headers_creator import headers_so_creator
 from onapsdk.vid import LineOfBusiness, Platform
-from onapsdk.configuration import settings
 
 from .so_element import OrchestrationRequest
 
 
 @dataclass
-class Operation:
-    """Operation class with data about method and suffix for VnfOperation."""
+class VnfParameter:
+    """Class to store vnf parameter used for preload.
 
-    request_method: str
-    request_suffix: str
+    IT'S DEPRECATED! `InstantiationParameter` SHOULD BE USED
 
-
-class VnfOperation(Operation):  # pylint: disable=too-few-public-methods
-    """Class to store possible operations' data for vnfs (request method and suffix)."""
-
-    UPDATE = Operation("PUT", "")
-    HEALTHCHECK = Operation("POST", "/healthcheck")
-
-
-@dataclass
-class SoServiceVfModule:
-    """Class to store a VfModule instance parameters."""
-
-    model_name: str
-    instance_name: str
-    parameters: Dict[str, Any] = field(default_factory=dict)
-    processing_priority: Optional[int] = None
-
-
-@dataclass
-class SoServiceXnf:
-    """Class to store a Xnf instance parameters."""
-
-    model_name: str
-    instance_name: str
-    parameters: Dict[str, Any] = field(default_factory=dict)
-    processing_priority: Optional[int] = None
-
-    @classmethod
-    def load(cls, data: Dict[str, Any]) -> "SoServiceVnf":
-        """Create a vnf instance description object from the dict.
-
-        Useful if you keep your instance data in file.
-
-        Returns:
-            SoServiceVnf: SoServiceVnf object created from the dictionary
-
-        """
-        return from_dict(data_class=cls, data=data)
-
-
-@dataclass
-class SoServiceVnf(SoServiceXnf):
-    """Class to store a Vnf instance parameters."""
-
-    vf_modules: List[SoServiceVfModule] = field(default_factory=list)
-
-
-@dataclass
-class SoServicePnf(SoServiceXnf):
-    """Class to store a Pnf instance parameters."""
-
-
-@dataclass
-class SoService:
-    """Class to store SO Service parameters used for macro instantiation.
-
-    Contains value list: List of vnfs to instantiate
-    Contains value: subscription service type
+    Contains two values: name of vnf parameter and it's value
     """
 
-    subscription_service_type: str
-    vnfs: List[SoServiceVnf] = field(default_factory=list)
-    pnfs: List[SoServicePnf] = field(default_factory=list)
-    instance_name: Optional[str] = None
-
-    @classmethod
-    def load(cls, data: Dict[str, Any]) -> "SoService":
-        """Create a service instance description object from the dict.
-
-        Useful if you keep your instance data in file.
-
-        Returns:
-            SoService: SoService object created from the dictionary
-
-        """
-        return from_dict(data_class=cls, data=data)
-
-
+    name: str
+    value: str
 
 @dataclass
 class VnfParameters:
@@ -259,6 +181,7 @@ class VfModuleInstantiation(Instantiation):  # pytest: disable=too-many-ancestor
             Iterator[VfModuleInstantiation]: VfModuleInstantiation class object.
 
         """
+        sdc_service: SdcService = vnf_instance.service_instance.service_subscription.sdc_service
         if vf_module_instance_name is None:
             vf_module_instance_name = \
                 f"Python_ONAP_SDK_vf_module_instance_{str(uuid4())}"
@@ -270,7 +193,6 @@ class VfModuleInstantiation(Instantiation):  # pytest: disable=too-many-ancestor
                 vnf_parameters
             )
             vnf_parameters = None
-        sdc_service: SdcService = vnf_instance.service_instance.sdc_service
         response: dict = cls.send_message_json(
             "POST",
             (f"Instantiate {sdc_service.name} "
@@ -299,7 +221,6 @@ class VfModuleInstantiation(Instantiation):  # pytest: disable=too-many-ancestor
             vf_module=vf_module
         )
 
-
 class NodeTemplateInstantiation(Instantiation, ABC):  # pytest: disable=too-many-ancestors
     """Base class for service's node_template object instantiation."""
 
@@ -426,9 +347,8 @@ class VnfInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-many-a
                               vnf_object: "Vnf",
                               line_of_business_object: "LineOfBusiness",
                               platform_object: "Platform",
-                              cloud_region: "CloudRegion",
-                              tenant: "Tenant",
-                              sdc_service: "SdcService",
+                              cloud_region: "CloudRegion" = None,
+                              tenant: "Tenant" = None,
                               vnf_instance_name: str = None,
                               vnf_parameters: Iterable["InstantiationParameter"] = None
                               ) -> "VnfInstantiation":
@@ -454,12 +374,13 @@ class VnfInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-many-a
             VnfInstantiation: VnfInstantiation object
 
         """
+        sdc_service: SdcService = aai_service_instance.service_subscription.sdc_service
         if vnf_instance_name is None:
             vnf_instance_name = \
                 f"Python_ONAP_SDK_vnf_instance_{str(uuid4())}"
         response: dict = cls.send_message_json(
             "POST",
-            (f"Instantiate {sdc_service.name} "
+            (f"Instantiate {aai_service_instance.service_subscription.sdc_service.name} "
              f"service vnf {vnf_object.name}"),
             (f"{cls.base_url}/onap/so/infra/serviceInstantiation/{cls.api_version}/"
              f"serviceInstances/{aai_service_instance.instance_id}/vnfs"),
@@ -487,168 +408,6 @@ class VnfInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-many-a
             vnf=vnf_object
         )
 
-    @classmethod
-    def instantiate_macro(cls,  # pylint: disable=too-many-arguments, too-many-locals
-                          aai_service_instance: "ServiceInstance",
-                          vnf_object: "Vnf",
-                          line_of_business: str,
-                          platform: str,
-                          cloud_region: "CloudRegion",
-                          tenant: "Tenant",
-                          sdc_service: "SdcService",
-                          vnf_instance_name: str = None,
-                          vnf_parameters: Iterable["InstantiationParameter"] = None,
-                          so_vnf: "SoServiceVnf" = None
-                          ) -> "VnfInstantiation":
-        """Instantiate Vnf using macro method.
-
-        Args:
-            aai_service_instance (ServiceInstance): Service instance associated with request
-            vnf_object (Vnf): Vnf to instantiate
-            line_of_business (LineOfBusiness): LineOfBusiness to use in instantiation request
-            platform (Platform): Platform to use in instantiation request
-            cloud_region (CloudRegion): Cloud region to use in instantiation request.
-            tenant (Tenant): Tenant to use in instantiation request.
-            vnf_instance_name (str, optional): Vnf instance name. Defaults to None.
-            vnf_parameters (Iterable[InstantiationParameter], optional): Instantiation parameters
-                that are sent in the request. Defaults to None
-            so_vnf (SoServiceVnf): object with vnf instance parameters
-
-        Returns:
-            VnfInstantiation: VnfInstantiation object
-
-        """
-        owning_entity_id = None
-        project = settings.PROJECT
-
-        for relationship in aai_service_instance.relationships:
-            if relationship.related_to == "owning-entity":
-                owning_entity_id = relationship.relationship_data.pop().get("relationship-value")
-            if relationship.related_to == "project":
-                project = relationship.relationship_data.pop().get("relationship-value")
-
-        owning_entity = OwningEntity.get_by_owning_entity_id(
-            owning_entity_id=owning_entity_id)
-
-        if so_vnf:
-            template_file = "instantiate_vnf_macro_so_vnf.json.j2"
-            if so_vnf.instance_name:
-                vnf_instance_name = so_vnf.instance_name
-        else:
-            template_file = "instantiate_vnf_macro.json.j2"
-            if vnf_instance_name is None:
-                vnf_instance_name = \
-                    f"Python_ONAP_SDK_vnf_instance_{str(uuid4())}"
-
-        response: dict = cls.send_message_json(
-            "POST",
-            (f"Instantiate {sdc_service.name} "
-             f"service vnf {vnf_object.name}"),
-            (f"{cls.base_url}/onap/so/infra/serviceInstantiation/{cls.api_version}/"
-             f"serviceInstances/{aai_service_instance.instance_id}/vnfs"),
-            data=jinja_env().get_template(template_file).render(
-                instance_name=vnf_instance_name,
-                vnf=vnf_object,
-                service=sdc_service,
-                cloud_region=cloud_region or \
-                             next(aai_service_instance.service_subscription.cloud_regions),
-                tenant=tenant or next(aai_service_instance.service_subscription.tenants),
-                project=project,
-                owning_entity=owning_entity,
-                line_of_business=line_of_business,
-                platform=platform,
-                service_instance=aai_service_instance,
-                vnf_parameters=vnf_parameters or [],
-                so_vnf=so_vnf
-            ),
-            headers=headers_so_creator(OnapService.headers)
-        )
-
-        return VnfInstantiation(
-            name=vnf_instance_name,
-            request_id=response["requestReferences"]["requestId"],
-            instance_id=response["requestReferences"]["instanceId"],
-            line_of_business=line_of_business,
-            platform=platform,
-            vnf=vnf_object
-        )
-
-    @classmethod
-    def so_action(cls,  # pylint: disable=too-many-arguments, too-many-locals
-                  vnf_instance: "VnfInstance",
-                  operation_type: VnfOperation,
-                  aai_service_instance: "ServiceInstance",
-                  line_of_business: str,
-                  platform: str,
-                  sdc_service: "SdcService",
-                  so_service: "SoService" = None
-                  ) -> "VnfInstantiation":
-        """Execute SO action (update or healthcheck) for selected vnf with SO macro request.
-
-        Args:
-            vnf_instance (VnfInstance): vnf instance object
-            operation_type (VnfOperation): name of the operation to trigger
-            aai_service_instance (AaiService): Service Instance object from aai
-            line_of_business (LineOfBusiness): LineOfBusiness name to use
-                in instantiation request
-            platform (Platform): Platform name to use in instantiation request
-            sdc_service (SdcService): Service model information
-            so_service (SoService, optional): SO values to use in SO request
-
-        Raises:
-            StatusError: if the provided operation is not supported
-
-        Returns:
-            VnfInstantiation: VnfInstantiation object
-
-        """
-        if operation_type not in (VnfOperation.HEALTHCHECK, VnfOperation.UPDATE):
-            raise StatusError("Operation not supported!")
-
-        owning_entity_id = None
-        project = settings.PROJECT
-
-        for relationship in aai_service_instance.relationships:
-            if relationship.related_to == "owning-entity":
-                owning_entity_id = relationship.relationship_data.pop().get("relationship-value")
-            if relationship.related_to == "project":
-                project = relationship.relationship_data.pop().get("relationship-value")
-
-        owning_entity = OwningEntity.get_by_owning_entity_id(
-            owning_entity_id=owning_entity_id)
-
-        response: dict = cls.send_message_json(
-            operation_type.request_method,
-            (f"So Action {sdc_service.name} "
-             f" vnf instance {vnf_instance.vnf_id}"),
-            (f"{cls.base_url}/onap/so/infra/serviceInstantiation/{cls.api_version}/"
-             f"serviceInstances/{aai_service_instance.instance_id}/vnfs/{vnf_instance.vnf_id}"
-             f"{operation_type.request_suffix}"),
-            data=jinja_env().get_template("instantiate_multi_vnf_service_macro.json.j2").render(
-                sdc_service=sdc_service,
-                cloud_region=next(aai_service_instance.service_subscription.cloud_regions),
-                tenant=next(aai_service_instance.service_subscription.tenants),
-                customer=aai_service_instance.service_subscription.customer,
-                project=project,
-                owning_entity=owning_entity,
-                line_of_business=line_of_business,
-                platform=platform,
-                service_instance_name=aai_service_instance.instance_name,
-                so_service=so_service
-            ),
-            headers=headers_so_creator(OnapService.headers)
-        )
-
-        return VnfInstantiation(
-            name=vnf_instance.vnf_name,
-            request_id=response["requestReferences"]["requestId"],
-            instance_id=response["requestReferences"]["instanceId"],
-            line_of_business=line_of_business,
-            platform=platform,
-            vnf=vnf_instance
-        )
-
-
 class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
     """Service instantiation class."""
 
@@ -692,7 +451,6 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
                                  customer: "Customer",
                                  owning_entity: "OwningEntity",
                                  project: "Project",
-                                 service_subscription: "ServiceSubscription",
                                  service_instance_name: str = None) -> "ServiceInstantiation":
         """Instantiate service using SO a'la carte request.
 
@@ -713,8 +471,7 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
         """
         warn("This method is deprecated, use `instantiate_ala_carte`.", DeprecationWarning)
         return cls.instantiate_ala_carte(sdc_service, cloud_region, tenant, customer,
-                                         owning_entity, project, service_subscription,
-                                         service_instance_name)
+                                         owning_entity, project, service_instance_name)
 
     @classmethod
     def instantiate_ala_carte(cls,  # pylint: disable=too-many-arguments
@@ -724,7 +481,6 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
                               customer: "Customer",
                               owning_entity: "OwningEntity",
                               project: "Project",
-                              service_subscription: "ServiceSubscription",
                               service_instance_name: str = None,
                               enable_multicloud: bool = False) -> "ServiceInstantiation":
         """Instantiate service using SO a'la carte request.
@@ -736,7 +492,6 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
             customer (Customer): Customer to use in instantiation request
             owning_entity (OwningEntity): Owning entity to use in instantiation request
             project (Project): Project to use in instantiation request
-            service_subscription (ServiceSubscription): Customer's service subsription.
             service_instance_name (str, optional): Service instance name. Defaults to None.
             enable_multicloud (bool, optional): Determines if Multicloud should be enabled
                 for instantiation request. Defaults to False.
@@ -767,8 +522,7 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
                 owning_entity=owning_entity,
                 service_instance_name=service_instance_name,
                 project=project,
-                enable_multicloud=enable_multicloud,
-                service_subscription=service_subscription
+                enable_multicloud=enable_multicloud
             ),
             headers=headers_so_creator(OnapService.headers)
         )
@@ -784,9 +538,8 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
             project=project
         )
 
-    # pylint: disable=too-many-arguments, too-many-locals
     @classmethod
-    def instantiate_macro(cls,
+    def instantiate_macro(cls,  # pylint: disable=too-many-arguments
                           sdc_service: "SdcService",
                           customer: "Customer",
                           owning_entity: "OwningEntity",
@@ -798,9 +551,7 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
                           tenant: "Tenant" = None,
                           service_instance_name: str = None,
                           vnf_parameters: Iterable["VnfParameters"] = None,
-                          enable_multicloud: bool = False,
-                          so_service: "SoService" = None,
-                          service_subscription: "ServiceSubscription" = None
+                          enable_multicloud: bool = False
                           ) -> "ServiceInstantiation":
         """Instantiate service using SO macro request.
 
@@ -820,9 +571,6 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
                 going to be used for vnfs instantiation. Defaults to None.
             enable_multicloud (bool, optional): Determines if Multicloud should be enabled
                 for instantiation request. Defaults to False.
-            so_service (SoService, optional): SO values to use in instantiation request
-            service_subscription(ServiceSubscription, optional): Customer service subscription
-                for the instantiated service. Required if so_service is not provided.
 
         Raises:
             StatusError: if a service is not distributed.
@@ -831,45 +579,34 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
             ServiceInstantiation: instantiation request object
 
         """
-        template_file = "instantiate_service_macro.json.j2"
-        if so_service:
-            template_file = "instantiate_multi_vnf_service_macro.json.j2"
-            if so_service.instance_name:
-                service_instance_name = so_service.instance_name
-        else:
-            if not service_subscription:
-                raise ParameterError("If no so_service is provided, "
-                                     "service_subscription parameter is required!")
-            if service_instance_name is None:
-                service_instance_name = f"Python_ONAP_SDK_service_instance_{str(uuid4())}"
         if not sdc_service.distributed:
             msg = f"Service {sdc_service.name} is not distributed."
             raise StatusError(msg)
+        if service_instance_name is None:
+            service_instance_name = f"Python_ONAP_SDK_service_instance_{str(uuid4())}"
 
         response: dict = cls.send_message_json(
             "POST",
             f"Instantiate {sdc_service.name} service macro",
             (f"{cls.base_url}/onap/so/infra/"
              f"serviceInstantiation/{cls.api_version}/serviceInstances"),
-            data=jinja_env().get_template(template_file). \
-                render(
-                    so_service=so_service,
-                    sdc_service=sdc_service,
-                    cloud_region=cloud_region,
-                    tenant=tenant,
-                    customer=customer,
-                    owning_entity=owning_entity,
-                    project=project,
-                    aai_service=aai_service,
-                    line_of_business=line_of_business,
-                    platform=platform,
-                    service_instance_name=service_instance_name,
-                    vnf_parameters=vnf_parameters,
-                    enable_multicloud=enable_multicloud,
-                    service_subscription=service_subscription
-                ),
+            data=jinja_env().get_template("instantiate_service_macro.json.j2").\
+            render(
+                sdc_service=sdc_service,
+                cloud_region=cloud_region,
+                tenant=tenant,
+                customer=customer,
+                owning_entity=owning_entity,
+                project=project,
+                aai_service=aai_service,
+                line_of_business=line_of_business,
+                platform=platform,
+                service_instance_name=service_instance_name,
+                vnf_parameters=vnf_parameters,
+                enable_multicloud=enable_multicloud
+            ),
             headers=headers_so_creator(OnapService.headers)
-            )
+        )
         return cls(
             name=service_instance_name,
             request_id=response["requestReferences"].get("requestId"),
@@ -884,7 +621,7 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
 
     @property
     def aai_service_instance(self) -> "ServiceInstance":
-        """Service instance associated with service instantiation request.
+        """Service instane associated with service instantiation request.
 
         Raises:
             StatusError: if a service is not instantiated -
@@ -963,6 +700,7 @@ class NetworkInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-ma
             NetworkInstantiation: NetworkInstantiation object
 
         """
+        sdc_service: SdcService = aai_service_instance.service_subscription.sdc_service
         if network_instance_name is None:
             network_instance_name = \
                 f"Python_ONAP_SDK_network_instance_{str(uuid4())}"
@@ -971,7 +709,7 @@ class NetworkInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-ma
                                               subnets=subnets)
         response: dict = cls.send_message_json(
             "POST",
-            (f"Instantiate {aai_service_instance.sdc_service.name} "
+            (f"Instantiate {aai_service_instance.service_subscription.sdc_service.name} "
              f"service network {network_object.name}"),
             (f"{cls.base_url}/onap/so/infra/serviceInstantiation/{cls.api_version}/"
              f"serviceInstances/{aai_service_instance.instance_id}/networks"),
@@ -979,7 +717,7 @@ class NetworkInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-ma
             render(
                 instance_name=network_instance_name,
                 network=network_object,
-                service=aai_service_instance.sdc_service,
+                service=sdc_service,
                 cloud_region=cloud_region or \
                     aai_service_instance.service_subscription.cloud_region,
                 tenant=tenant or aai_service_instance.service_subscription.tenant,
